prettyconf
==========

|Build Status| |Coverage Status| |Docs| |Codacy| |Landscape|

Pretty Conf is a Python library created to make easy the separation of
configuration and code following the recomendations of `12 Factor`_'s topic
about configs.

It is strongly inspired in `python-decouple`_ and both provides a similar
API.


Documentation
-------------

You can find ``prettyconf`` documentation at `Read the Docs`_ website.


.. _`12 Factor`: http://12factor.net/
.. _`Read the Docs`: http://prettyconf.readthedocs.org/
.. _`python-decouple`: https://github.com/henriquebastos/python-decouple

.. |Build Status| image:: https://travis-ci.org/osantana/prettyconf.png?branch=master
   :target: https://travis-ci.org/osantana/prettyconf
.. |Coverage Status| image:: https://coveralls.io/repos/osantana/prettyconf/badge.svg?branch=master
   :target: https://coveralls.io/r/osantana/prettyconf?branch=master
.. |Docs| image:: https://readthedocs.org/projects/prettyconf/badge/?version=latest
   :target: https://readthedocs.org/projects/prettyconf/?badge=latest
.. |Codacy| image:: https://api.codacy.com/project/badge/grade/65576e834eb74d529921d8625347a5a1
    :target: https://www.codacy.com/app/osantana/prettyconf
.. |Landscape| image:: https://landscape.io/github/osantana/prettyconf/master/landscape.svg?style=flat
   :target: https://landscape.io/github/osantana/prettyconf/master
